library(metR)
# library(vdiffr)

context("contour_fill")

# test_that("geom_contour_fill works", {
#     expect_doppelganger("contour_fill-base",
#                         ggplot(geopotential[date == date[1]], aes(lon, lat)) +
#                             geom_contour_fill(aes(z = gh)))
#     expect_doppelganger("contour_fill-base",
#                         ggplot(geopotential[date == date[1]], aes(lon, lat)) +
#                             stat_contour_fill(aes(z = gh)))
# })

